/**************************************************************************//**
 * @file
 * @brief VCMP - Voltage Comparator prototypes and definitions
 * @author shondll
 * @version 1.0.0
 ******************************************************************************
 *
 *****************************************************************************/

#ifndef _VCMP_H
#define _VCMP_H

#include "efm32.h"

#define VCMP_INITIAL_LEVEL 30 // ~2.7V

/*************************************************************************
 * Function Name: VCMP_GetResult
 * Parameters: none
 *
 * Return:	0 - still in progress
 *			1 - Vdd above set level
 *			-1 - Vdd below set level
 *
 * Description: returns Vdd voltage level compared to the set reference
 *
 *************************************************************************/
int VCMP_GetResult(void);

/*************************************************************************
 * Function Name: VCMP_SetLevel
 * Parameters: level - reference to the comparator (0..63)
 * Select VDD trigger level. Vtrig = 1.667V + (0.034V * level)
 *
 * Return: none
 *
 * Description: Sets new reference level for the comparator
 *
 *************************************************************************/
void VCMP_SetLevel(int level);

/*************************************************************************
 * Function Name: VCMP_GetLevel
 * Parameters: none
 *
 * Return: none
 * Select VDD trigger level. Vtrig = 1.667V + (0.034V * level)
 *
 * Description: Gets current reference level for the comparator
 *
 *************************************************************************/
int VCMP_GetLevel(void);

/*************************************************************************
 * Function Name: VCMP_Init
 * Parameters: none
 *
 * Return: none
 *
 * Description: initializes registers in the VCMP module
 *
 *************************************************************************/
void VCMP_Init(void);

#endif
